@@ -10,6 +10,7 @@ from ...models.http_validation_error import HTTPValidationError
 from ...models.method_ad import MethodAD
 from ...models.method_cd import MethodCD
 from ...models.method_cpt import MethodCPT
+from ...models.method_def import MethodDEF
 from ...models.method_dp import MethodDP
 from ...models.method_dt import MethodDT
 from ...models.method_esa import MethodESA
@@ -24,13 +25,15 @@ from ...models.method_rp import MethodRP
 from ...models.method_rs import MethodRS
 from ...models.method_rws import MethodRWS
 from ...models.method_sa import MethodSA
+from ...models.method_slb import MethodSLB
 from ...models.method_spt import MethodSPT
-from ...models.method_sr import MethodSR
 from ...models.method_srs import MethodSRS
 from ...models.method_ss import MethodSS
+from ...models.method_sti import MethodSTI
 from ...models.method_svt import MethodSVT
 from ...models.method_tot import MethodTOT
 from ...models.method_tp import MethodTP
+from ...models.method_tr import MethodTR
 from ...models.method_type_enum_str import MethodTypeEnumStr
 from ...models.method_wst import MethodWST
 from ...types import UNSET, Response, Unset
@@ -71,6 +74,7 @@ def _parse_response(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -85,13 +89,15 @@ def _parse_response(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]
         ],
@@ -108,6 +114,7 @@ def _parse_response(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -122,13 +129,15 @@ def _parse_response(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]:
                 try:
@@ -254,7 +263,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_15 = MethodAD.from_dict(data)
+                    response_200_item_type_15 = MethodTR.from_dict(data)
 
                     return response_200_item_type_15
                 except:  # noqa: E722
@@ -262,7 +271,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_16 = MethodRO.from_dict(data)
+                    response_200_item_type_16 = MethodAD.from_dict(data)
 
                     return response_200_item_type_16
                 except:  # noqa: E722
@@ -270,7 +279,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_17 = MethodINC.from_dict(data)
+                    response_200_item_type_17 = MethodRO.from_dict(data)
 
                     return response_200_item_type_17
                 except:  # noqa: E722
@@ -278,7 +287,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_18 = MethodSR.from_dict(data)
+                    response_200_item_type_18 = MethodINC.from_dict(data)
 
                     return response_200_item_type_18
                 except:  # noqa: E722
@@ -286,7 +295,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_19 = MethodIW.from_dict(data)
+                    response_200_item_type_19 = MethodDEF.from_dict(data)
 
                     return response_200_item_type_19
                 except:  # noqa: E722
@@ -294,7 +303,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_20 = MethodDT.from_dict(data)
+                    response_200_item_type_20 = MethodIW.from_dict(data)
 
                     return response_200_item_type_20
                 except:  # noqa: E722
@@ -302,7 +311,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_21 = MethodOTHER.from_dict(data)
+                    response_200_item_type_21 = MethodDT.from_dict(data)
 
                     return response_200_item_type_21
                 except:  # noqa: E722
@@ -310,7 +319,7 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_22 = MethodSRS.from_dict(data)
+                    response_200_item_type_22 = MethodOTHER.from_dict(data)
 
                     return response_200_item_type_22
                 except:  # noqa: E722
@@ -318,16 +327,40 @@ def _parse_response(
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    response_200_item_type_23 = MethodDP.from_dict(data)
+                    response_200_item_type_23 = MethodSRS.from_dict(data)
 
                     return response_200_item_type_23
                 except:  # noqa: E722
                     pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    response_200_item_type_24 = MethodDP.from_dict(data)
+
+                    return response_200_item_type_24
+                except:  # noqa: E722
+                    pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    response_200_item_type_25 = MethodWST.from_dict(data)
+
+                    return response_200_item_type_25
+                except:  # noqa: E722
+                    pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    response_200_item_type_26 = MethodSLB.from_dict(data)
+
+                    return response_200_item_type_26
+                except:  # noqa: E722
+                    pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_item_type_24 = MethodWST.from_dict(data)
+                response_200_item_type_27 = MethodSTI.from_dict(data)
 
-                return response_200_item_type_24
+                return response_200_item_type_27
 
             response_200_item = _parse_response_200_item(response_200_item_data)
 
@@ -354,6 +387,7 @@ def _build_response(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -368,13 +402,15 @@ def _build_response(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]
         ],
@@ -404,6 +440,7 @@ def sync_detailed(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -418,13 +455,15 @@ def sync_detailed(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]
         ],
@@ -446,7 +485,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]]
+        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]]
     """
 
     kwargs = _get_kwargs(
@@ -480,6 +519,7 @@ def sync(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -494,13 +534,15 @@ def sync(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]
         ],
@@ -522,7 +564,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]
+        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
     """
 
     return sync_detailed(
@@ -551,6 +593,7 @@ async def asyncio_detailed(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -565,13 +608,15 @@ async def asyncio_detailed(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]
         ],
@@ -593,7 +638,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]]
+        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]]
     """
 
     kwargs = _get_kwargs(
@@ -625,6 +670,7 @@ async def asyncio(
                 "MethodAD",
                 "MethodCD",
                 "MethodCPT",
+                "MethodDEF",
                 "MethodDP",
                 "MethodDT",
                 "MethodESA",
@@ -639,13 +685,15 @@ async def asyncio(
                 "MethodRS",
                 "MethodRWS",
                 "MethodSA",
+                "MethodSLB",
                 "MethodSPT",
-                "MethodSR",
                 "MethodSRS",
                 "MethodSS",
+                "MethodSTI",
                 "MethodSVT",
                 "MethodTOT",
                 "MethodTP",
+                "MethodTR",
                 "MethodWST",
             ]
         ],
@@ -667,7 +715,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]
+        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
     """
 
     return (
