@@ -1,4 +1,5 @@
 import datetime
+from collections.abc import Mapping
 from typing import Any, Literal, TypeVar, Union, cast
 from uuid import UUID
 
@@ -36,10 +37,10 @@ class MethodSRSCreate:
         method_type_id (Union[Literal[24], Unset]):  Default: 24.
         sounding_class (Union[Unset, SoundingClass]): Soil-Rock-Sounding (Swedish Jord-bergsondering) classes
             (
-            JB1 = Jb-1,
-            JB2 = Jb-2,
-            JB3 = Jb-3,
-            JBTOT = Jb-tot,
+            JB1 = JB1,
+            JB2 = JB2,
+            JB3 = JB3,
+            JBTOT = JBTOT,
             )
         serial_number (Union[None, Unset, str]):
         calibration_date (Union[None, Unset, datetime.datetime]):
@@ -189,8 +190,8 @@ class MethodSRSCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
         def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
             if data is None:
