@@ -1,4 +1,5 @@
 import datetime
+from collections.abc import Mapping
 from typing import Any, Literal, TypeVar, Union, cast
 from uuid import UUID
 
@@ -171,8 +172,8 @@ class MethodTOTData:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
         method_data_id = UUID(d.pop("method_data_id"))
 
         method_id = UUID(d.pop("method_id"))
